==> apache-beam-2.45.0-source-release.zip: beam-2.45.0/sdks/go/pkg/beam/core/funcx/output_test.go <==
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package funcx

import (
	"reflect"
	"testing"

	"github.com/apache/beam/sdks/v2/go/pkg/beam/core/typex"
)

func TestIsEmit(t *testing.T) {
	tests := []struct {
		Fn  any
		Exp bool
	}{
		{func() {}, false}, // no values
		{func(string) {}, true},
		{func(string) bool { return true }, false}, // return value
		{func(string, int) {}, true},
		{func(typex.T, string) {}, true},
		{func(typex.Z, typex.Z) {}, true},
		{func(typex.EventTime) {}, false}, // no actual values
		{func(typex.EventTime, string) {}, true},
		{func(typex.EventTime, typex.T, typex.X) {}, true},
		{func(typex.EventTime, typex.T, typex.X, int) {}, false}, // too many values
	}

	for _, test := range tests {
		val := reflect.TypeOf(test.Fn)
		if actual := IsEmit(val); actual != test.Exp {
			t.Errorf("IsEmit(%v) = %v, want %v", val, actual, test.Exp)
		}
	}
}

==> apache-beam-2.70.0-source-release.zip: beam-2.70.0/sdks/go/pkg/beam/core/funcx/output_test.go <==
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package funcx

import (
	"reflect"
	"testing"

	"github.com/apache/beam/sdks/v2/go/pkg/beam/core/typex"
)

func TestIsEmit(t *testing.T) {
	tests := []struct {
		Fn  any
		Exp bool
	}{
		{func() {}, false}, // no values
		{func(string) {}, true},
		{func(string) bool { return true }, false}, // return value
		{func(string, int) {}, true},
		{func(typex.T, string) {}, true},
		{func(typex.Z, typex.Z) {}, true},
		{func(typex.EventTime) {}, false}, // no actual values
		{func(typex.EventTime, string) {}, true},
		{func(typex.EventTime, typex.T, typex.X) {}, true},
		{func(typex.EventTime, typex.T, typex.X, int) {}, false}, // too many values
		{func(any) {}, false},                                    // any is not allowed as a param
		{func(*any) {}, false},                                   // *any is also not allowed
	}

	for _, test := range tests {
		val := reflect.TypeOf(test.Fn)
		if actual := IsEmit(val); actual != test.Exp {
			t.Errorf("IsEmit(%v) = %v, want %v", val, actual, test.Exp)
		}
	}
}
